@@ -73,7 +73,7 @@ class FreqDict(models.Model):
             lem = Lemma.objects.filter(pk=int(wfs[key]['IdLemma']))
             if len(lem) != 1:
                 continue
-            wf = WordForm.objects.create(pk=int(key),Lemma = lem,Frequency = int(wfs[key]['Freq']))
+            wf = WordForm.objects.create(pk=int(key),Lemma = lem[0],Frequency = int(wfs[key]['Freq']))
             ss = (Orthography.objects.get_or_create(Spelling=s)[0] for s in wfs[key]['Spellings'])
             wf.Orthographies.add(*ss)
             ts = (Transcription.objects.get_or_create(Transcription=t)[0] for t in wfs[key]['Transcriptions'])
